@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 import os
 import shutil
-from __init__ import Logya
-from writer import DocWriter
+
+from logya.core import Logya
+from logya.writer import DocWriter
 
 
 class Generate(Logya):
@@ -13,7 +14,7 @@ class Generate(Logya):
         super(self.__class__, self).__init__(**kwargs)
         self.init_env()
 
-        # init writer before executing scripts, so they can use it
+        # Init writer before executing scripts, so they can use it.
         self.writer = DocWriter(self.dir_dst, self.template)
 
         self.info("Remove existing deploy directory")
@@ -25,8 +26,8 @@ class Generate(Logya):
             self.info("Copy static files")
             shutil.copytree(self.dir_static, self.dir_dst)
 
-        # execute scripts in before building indexes, so that generated content
-        # can be indexed too
+        # Execute scripts in before building indexes, so that generated content
+        # can be indexed too.
         self.info("Execute scripts in bin dir")
         self.exec_bin()
 
@@ -34,9 +35,8 @@ class Generate(Logya):
         self.build_indexes()
 
         self.info("Write documents to deploy directory")
-        for doc in self.docs_parsed.itervalues():
+        for doc in list(self.docs_parsed.values()):
             self.writer.write(doc, self.get_doc_template(doc))
 
         self.info("Write indexes")
         self.write_indexes()
-
